==> com.liferay.dynamic.data.mapping.form.builder-2.0.81-sources-commercial.jar: META-INF/resources/js/components/LayoutProvider/handlers/fieldClickedHandler.es.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import * as FormSupport from 'dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es';
import {PagesVisitor} from 'dynamic-data-mapping-form-renderer/js/util/visitors.es';

const handleFieldClicked = (state, event) => {
	const {columnIndex, pageIndex, rowIndex} = event;
	const {pages} = state;

	const fieldProperties = FormSupport.getField(
		pages,
		pageIndex,
		rowIndex,
		columnIndex
	);
	const {settingsContext} = fieldProperties;
	const visitor = new PagesVisitor(settingsContext.pages);

	const focusedField = {
		...fieldProperties,
		columnIndex,
		pageIndex,
		rowIndex,
		settingsContext: {
			...settingsContext,
			pages: visitor.mapFields(field => {
				const {fieldName} = field;

				if (fieldName === 'name') {
					field.visible = true;
				}
				else if (fieldName === 'label') {
					field.type = 'text';
				}
				else if (fieldName === 'validation') {
					field = {
						...field,
						validation: {
							...field.validation,
							fieldName: fieldProperties.fieldName
						}
					};
				}

				return field;
			})
		}
	};

	return {
		focusedField: {
			...focusedField,
			columnIndex,
			pageIndex,
			rowIndex
		},
		previousFocusedField: focusedField
	};
};

export default handleFieldClicked;

==> com.liferay.dynamic.data.mapping.form.builder-3.0.9-sources-commercial.jar: META-INF/resources/js/components/LayoutProvider/handlers/fieldClickedHandler.es.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {FormSupport, PagesVisitor} from 'dynamic-data-mapping-form-renderer';

import {localizeField} from '../../../util/fieldSupport.es';

const handleFieldClicked = (props, state, event) => {
	const {columnIndex, pageIndex, rowIndex} = event;
	const {pages} = state;

	const fieldProperties = FormSupport.getField(
		pages,
		pageIndex,
		rowIndex,
		columnIndex
	);
	const {settingsContext} = fieldProperties;
	const visitor = new PagesVisitor(settingsContext.pages);

	const focusedField = {
		...fieldProperties,
		columnIndex,
		pageIndex,
		rowIndex,
		settingsContext: {
			...settingsContext,
			pages: visitor.mapFields(field => {
				const {fieldName} = field;
				const {defaultLanguageId, editingLanguageId} = props;

				if (fieldName === 'name') {
					field.visible = true;
				}
				else if (fieldName === 'label') {
					field.type = 'text';
				}
				else if (fieldName === 'validation') {
					field = {
						...field,
						validation: {
							...field.validation,
							fieldName: fieldProperties.fieldName,
						},
					};
				}

				return localizeField(
					field,
					defaultLanguageId,
					editingLanguageId
				);
			}),
		},
	};

	return {
		focusedField: {
			...focusedField,
			columnIndex,
			pageIndex,
			rowIndex,
		},
		previousFocusedField: focusedField,
	};
};

export default handleFieldClicked;
